==> groupoffice-6.1.80.txz: usr/local/www/groupoffice6/modules/addressbook/language/en.php <==
<?php
$l['name'] = 'Address book';
$l['description'] = 'Module to manage all contacts.';

$l['addresslists']='Address Lists';
$l["newSearch"]='New search';
$l["executeQuery"]='Execute search query';
$l["savedQueries"]='Saved search queries';
$l["selectField"]= 'Select field';
$l["cmdFormLabelAddressBooks"]= 'Address Book';
$l["alphabet"]= 'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z';
$l["cmdAllFields"]= 'All fields';
$l["btnAddContact"]= 'Add Contact'	;
$l["btnAddCompany"]= 'Add Company';
$l["btnManage"]= 'Manage';
$l["btnDownload"]= 'Download File';
$l["cmdFormSearchFirst"]= 'Search in= ';
$l["cmdFormSearchSecond"]= ' on= ';
$l["cmdFormSearchThird"]= ' for= ';
$l["cmdFormSearchFourth"]= '(Use \'%\' as a wildcard) ';
$l["cmdFormLabelTitleInitials"]= 'Title/Initials';
$l["cmdFormLabelSalutation"]= 'Salutation';
$l["cmdFormLabelComment"]= 'Comment';
$l["cmdFormCompanyEmptyText"]= 'Please select a company';
$l["cmdFieldsetSelectAddressbook"]= 'Select address book';
$l["cmdFieldsetPersonalDetails"]= 'Personal details';
$l["cmdFieldsetAddress"]= 'Address';
$l["cmdFieldsetContact"]= 'Contact details';
$l["cmdFieldsetCompany"]= 'Company details';
$l["cmdFieldsetWork"]= 'Work';
$l["cmdPanelContact"]= 'Contact details';
$l["cmdPanelComments"]= 'Comments';
$l["cmdSalutation"]= 'Dear';
$l["cmdMadam"]= 'madam';
$l["cmdSir"]= 'sir';
$l["btnDownloadTextDocument"]= 'Download TextDocument';
$l["cmdContactDetailsFor"]= 'Personal details for';
$l["cmdLInkFieldset"]= 'Links';
$l["cmdCompanyDetailsFor"]= 'Details for';
$l["cmdPanelCompany"]= 'Company details';
$l["cmdFormLabelBankNo"]= 'Bank number';
$l['bankBicNo'] = 'Bank BIC number';
$l["cmdFormLabelVatNo"]= 'VAT number';
$l["cmdFormLabelInvoiceEmail"]= 'Invoicing email';
$l["cmdFieldsetCompanyDetails"]= 'Company details';
$l["cmdCompanyDialog"]= 'Edit company';
$l["cmdPanelEmployees"]= 'Employees';
$l["cmdPanelEmployee"]= 'Employee';
$l["cmdAllEmployeesForThisCompany"]= 'All Employees for this company';
$l["cmdFieldsetVisitAddress"]= 'Visit address';
$l["cmdFieldsetPostAddress"]= 'Post address';
$l["cmdManageDialog"]= 'Manage';
$l["cmdAddAddressBook"]= 'Add address book';
$l["cmdDeleteAddressbook"]= 'Delete address book';
$l["cmdOwner"]= 'Owner';
$l["cmdPanelAddressbook"]= 'Address books';
$l["cmdPanelProperties"]= 'Properties';
$l["cmdContactDialog"]= 'Edit contact';
$l["cmdFormLabelFileType"]= 'File type';
$l["cmdFormLabelFile"]= 'File';	;
$l["cmdFormLabelValueSeperated"]= 'Values separated by';
$l["cmdFormLabelValueIncluded"]= 'Values encapsulated by';
$l["cmdFormLabelLinesEnded"]= 'Lines ended by';
$l["cmdUpload"]= 'Upload';
$l["cmdImport"]= 'Import';
$l["cmdExport"]= 'Export';
$l["users"]= 'Users';
$l["strSelectContact"]= 'Select contact';
$l["strSelectCompany"]= 'Select company';
$l["noAddressbooks"]= 'There are no address books';
$l["moveAll"]= 'The company and all employees will also be moved to the new address book. Are you sure you want to do this?';
$l["addressbook"]= 'Address book';
$l["addressbooks"]= 'Address books';
$l["sendMailing"]='Send mailing';
$l["importSuccessCount"]='Records imported successfully:';
$l["importSuccess"]='Records imported successfully!';
$l["searchOnSender"]='Lookup in address book';
$l["confirmCreate"]='Contact doesn\'t exist. Do you wish to create a new contact?';
$l["matchFields"]='Match the fields';
$l["advancedSearch"]='Advanced search';
$l["defaultAddressFormat"]='Default address format';
$l["defaultSalutation"]='Default salutation';
$l["explanationVariables"]='Explanation default salutation variables';
$l["explanationSex"]='Male and female form of salutation';
$l["searchQueryName"]='Search query name';
$l["enterSearchQueryName"]='Enter the name of the search query:';
$l["photo"]= 'Photo';
$l["deleteImage"]='Delete image';
$l["addAllSearchResults"]='Add all search results';
$l["confirmAddAllSearchResults"]='Are you sure you want to add all the search results to the address list?';
$l["moveEmployees"]='Move employees';
$l["emailAdded"]='Email address succesfully added to contact';
$l["exportWithCompanies"]='With companies';
$l["id"]='ID';
$l["exportPermission"]='Export permissions';
$l["crn"]='Company Reg. No.';
$l["iban"]='IBAN';
$l["unknownEmail"]= 'Unknown email address';
$l["strUnknownEmail"]= 'This email address is unknown. Do want to add this to a new contact or an existing contact?';
$l["newContact"] = "New Contact";
$l["existingContact"] = "Existing Contact";
$l["globalsettings_templatelabel"]= 'Template';
$l["globalsettings_allchangelabel"]= 'Change all?';
$l["globalsettings_renameall"]= 'Rename all?';
$l["createEmailSelected"]= 'Create email for selection';

$l['allAddressbooks'] = 'All Address books';
$l['notIncluded'] = 'Do not import';
$l['comment'] = 'Comment';
$l['bankNo'] = 'Bank number'; ;
$l['vatNo'] = 'VAT number';
$l['contactsGroup'] = 'Group';
$l['contact'] = 'Contact';
$l['company'] = 'Company';
$l['customers'] = 'Customers';
$l['suppliers'] = 'Suppliers';
$l['prospects'] = 'Prospects';
$l['contacts'] = 'Contacts';
$l['companies'] = 'Companies';
$l['newContactAdded']='New contact added';
$l['newContactFromSite']='New contact data have been added through a website form.';
$l['clickHereToView']='Click here to view the contact';
$l['contactFromAddressbook']='Contact from %s';
$l['companyFromAddressbook']='Company from %s';
$l['defaultSalutationTpl']='Dear [Mr./Mrs.] {middle_name} {last_name}';
$l['multipleSelected']='Multiple address books selected';
$l['incomplete_delete_contacts']='You don\'t have permission to delete all selected contacts';
$l['incomplete_delete_companies']='You don\'t have permission to delete all selected companies';
$l['emailAlreadyExists']='E-mail address is already added to this contact';
$l['emailDoesntExists']='E-mail address wasn\'t found';
$l['imageNotSupported']='The image you uploaded is not supported. Only gif, png and jpg images are supported.';
$l['no_addressbook_id'] = 'Invalid address book id has been passed with the request to the server!';
$l['undefined'] = '-';
$l['addresslistContact'] = 'Address list contact';

$l["companyId"] = "ID";
$l["companyUser_id"] = "User";
$l["companyAddressbook_id"] = "Addressbook";
$l["companyName"] = "Name";
$l["companyName2"] = "Name 2";
$l["companyAddress"] = "Address";
$l["companyAddress_no"] = "Address 2";
$l["companyZip"] = "ZIP/Postal";
$l["companyCity"] = "City";
$l["companyState"] = "State";
$l["companyCountry"] = "Country";
$l["companyPost_address"] = "Post Address";
$l["companyPost_address_no"] = "Post Address 2";
$l["companyPost_city"] = " Post City";
$l["companyPost_state"] = "Post State";
$l["companyPost_country"] = "Post Country";
$l["companyPost_zip"] = "Post ZIP/Postal";
$l["companyPhone"] = "Phone";
$l["companyFax"] = "Fax";
$l["companyEmail"] = "E-mail";
$l["companyHomepage"] = "Homepage";
$l["companyComment"] = "Comments";
$l["companyBank_no"] = "Bank Number";
$l["companyVat_no"] = "VAT Number";
$l["companyIban"] = "IBAN";
$l["companyCrn"] = "CRN";
$l["companyCtime"] = "Creation Time";
$l["companyMtime"] = "Modification Time";
$l["companyEmail_allowed"] = "Email allowed";
$l["companyFiles_folder_id"] = "Folder";

$l["contactId"] = "ID";
$l["contactUser_id"] = "User";
$l["contactAddressbook_id"] = "Addressbook";
$l["contactFirst_name"] = "First name";
$l["contactMiddle_name"] = "Middle name";
$l["contactLast_name"] = "Last name";
$l["contactInitials"] = "Initials";
$l["contactTitle"] = "Title";
$l["contactSex"] = "Sex";
$l["contactBirthday"] = "Birthday";
$l["contactEmail"] = "E-mail";
$l["contactEmail2"] = "E-mail 2";
$l["contactEmail3"] = "E-mail 3";
$l["contactCompany_id"] = "Company";
$l["contactDepartment"] = "Department";
$l["contactFunction"] = "Function";
$l["contactHome_phone"] = "Phone (Home)";
$l["contactWork_phone"] = "Phone (Work)";
$l["contactFax"] = "Fax (Home)";
$l["contactWork_fax"] = "Fax (Work)";
$l["contactCellular"] = "Mobile";
$l["contactCellular2"] = "2nd Mobile";
$l["contactCountry"] = "Country";
$l["contactState"] = "State";
$l["contactCity"] = "City";
$l["contactZip"] = "Zipcode";
$l["contactAddress"] = "Address";
$l["contactAddress_no"] = "Address number";
$l["contactComment"] = "Comments";
$l["contactCtime"] = "Creation time";
$l["contactMtime"] = "Modification time";
$l["contactSalutation"] = "Salutation";
$l["contactEmail_allowed"] = "Email allowed";
$l["contactFiles_folder_id"] = "Folder";
$l["contactGo_user_id"] = "User";
$l["contactSuffix"] = "Suffix";
$l["contactHomepage"] = "Homepage";

$l['mailingStatus'][0]="Waiting to start";
$l['mailingStatus'][1]="Running";
$l['mailingStatus'][2]="Finished";
$l['mailingStatus'][3]="Paused";

$l['createUser']='Create user';



$l["cmdPanelTemplate"]= 'Templates';
$l["cmdAddEmailTemplate"]= 'Add e-mail template';
$l["cmdAddOpenOfficeTemplate"]= 'Add OpenOffice.org template';
$l["cmdType"]= 'Type';
$l["cmdTemplateDialog"]= 'Edit template';
$l["cmdFormLabelReadNotification"]= 'Request the recipient to send a read notification';
$l["cmdAddMailing"]= 'Add address list';
$l["cmdDeleteMailing"]= 'Delete address list';
$l["cmdPanelMailings"]= 'Address lists';
$l["cmdEditMailingWindow"]= 'Edit address list';
$l["SelectOODocument"]= 'Select a template';
$l["SelectOODocumentWindowTitle"]= 'Select OpenOffice document';
$l["autoDataMyName"]= 'My Name';
$l["autoDataBeginning"]= 'Beginning';
$l["emailTemplate"]= 'E-mail template';
$l["sendingEmailAllowed"]= 'Sending e-mails to this e-mail address is allowed';
$l["enabledMailingGroups"]= 'Enabled address lists:';
$l["autoData"]= 'Autodata';
$l["selectMailingGroup"]='Select an address list';
$l["noMailingGroups"]='You don\'t have any address list';
$l["sentMailings"]='Sent newsletters';
$l["subject"]='Subject';
$l['status']='Status';
$l["sent"]='Sent';
$l["total"]='Total';
$l["errors"]='Errors';
$l["addEntireAddressbook"]='Add entire address book';
$l["selectAddressbook"]='Select an addressbook';
$l["defaultSalutationText"]='Enter a salutation that is used when the salutation for the recipient is unknown';
$l["filterMailings"]='Address list filter';
$l["enterName"]='Enter filename';
$l["pleaseEnterName"]='Please enter a filename for the new document';
$l["noAddressLists"]='No address lists';
$l["confirmAddEntireAddressbook"]='Are you sure you want to add everything in this addressbook to this addresslist?';
$l["noTemplate"]='No template';
$l["customContactFields"]='Custom contact fields';
$l["customCompanyFields"]='Custom company fields';
$l["customUserFields"]='Custom user fields';
$l["newsletters"]='Newsletters';
$l["addresslist"]='Address list';
$l["viewLog"]='View log';
$l["viewMessage"]='View message';
$l["pauseMailing"]='Pause sending';
$l["resumeMailing"]='Resume sending';
$l["unsubscribeLink"]='Unsubscribe link';
$l["unsubscribeHref"]='Unsubscribe href';
$l["addDocumentTemplate"]='Add document template';
$l["documentTemplate"]='Document template';


$l['templateAlreadyExists'] = 'The template you are trying to create already exists';
$l['mailingAlreadyExists'] = 'The mailing you are trying to create already exists';
$l['greet']='Best regards';
$l['unsubscribe']='Unsubscribe';
$l['unsubscription']='Click here to unsubscribe from this address list.';
$l['r_u_sure'] = 'Are you sure you want to unsubscribe from the address list?';
$l['delete_success'] = 'You have been successfully unsubscribed from the address list.';
$l['setCurrentTemplateAsDefault']='Set current template as default for myself';

$l['contactCustomFields']='Contacts custom fields';
$l['companyCustomFields']='Company custom fields';
$l['editUser']='Edit user';

$l['templateContent']='Document';

$l['addresslistIdMustBePositive']='This panel expects an address list ID that is positive, but did not receive one. Please contact the administrator.';
$l['male']='Male';
$l['female']='Female';
$l['importing']='Importing';
$l['contactUuid']='UUID';
$l['nRemovedFromAddresslist']='%n contacts have been identified and removed from the selected address list.';

$l['addToAddresslist']='Add to address list %s';
$l['addToAddresslistPrompt']='You are about to add the selected items to the address list %s. Do you want these items to exist only in %s?';
$l['addAddresslistSuccess']='The items have been successfully added to the address list.';

$l['addContactsSuccess'] = '%i contacts have been succesfully added to the address list.';

$l['searchForImages']='Search for images';
$l['downloadPhotoUrl']='Download photo URL';
$l['orBrowseComputer']='or upload from your computer';

$l['currentImage']='Current image';
$l['downloadFullImage']='Download full image';

$l['upcomingBirthdays'] = "Upcoming birthdays";
$l['age'] = "Age";
$l['actionDate']='Action date';
$l['selectCurrentActions']='Show active';
$l['showActieveToolTip']='Show only contacts that have a current action date.';
$l['linkedinUrl'] = 'LinkedIn URL';
$l['facebookUrl'] = 'Facebook URL';
$l['twitterUrl'] = 'Twitter URL';
$l['skypeName'] = 'Skype name';
$l['cmdPanelSocialMedia'] = 'Social media';

$l['setCurrentTemplateAsDefaultEAccount']='Set current template as default for this email account';

$l['callOnSkype'] = 'Call on Skype';

$l['userDefaultTemplate'] = 'User default template';

$l['exportContacts'] = 'Personal info';
$l['exportContactsWithCompanies'] = 'Personal and company info';

$l['privateAddress'] = 'Private address';
$l['exportContactsWithCompanies'] = 'Contacts with companies';

$l['mustBeSameAddressbook'] = 'The company of the contact must be in the same address book as the contact. Contact not saved.';
$l['exportContactsAsVcard'] = 'Export contacts as vcard';

$l["addEmployee"] = 'Add new';
$l["addExistingEmployee"] = 'Add existing';

==> groupoffice-6.2.19.txz: usr/local/www/groupoffice6/modules/addressbook/language/en.php <==
<?php
$l['name'] = 'Address book';
$l['description'] = 'Module to manage all contacts.';

$l['addresslists']='Address Lists';
$l["newSearch"]='New search';
$l["executeQuery"]='Execute search query';
$l["savedQueries"]='Saved search queries';
$l["selectField"]= 'Select field';
$l["cmdFormLabelAddressBooks"]= 'Address Book';
$l["alphabet"]= 'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z';
$l["cmdAllFields"]= 'All fields';
$l["btnAddContact"]= 'Add Contact'	;
$l["btnAddCompany"]= 'Add Company';
$l["btnManage"]= 'Manage';
$l["btnDownload"]= 'Download File';
$l["cmdFormSearchFirst"]= 'Search in= ';
$l["cmdFormSearchSecond"]= ' on= ';
$l["cmdFormSearchThird"]= ' for= ';
$l["cmdFormSearchFourth"]= '(Use \'%\' as a wildcard) ';
$l["cmdFormLabelTitleInitials"]= 'Title/Initials';
$l["cmdFormLabelSalutation"]= 'Salutation';
$l["cmdFormLabelComment"]= 'Remark';
$l["cmdFormCompanyEmptyText"]= 'Please select a company';
$l["cmdFieldsetSelectAddressbook"]= 'Select address book';
$l["cmdFieldsetPersonalDetails"]= 'Personal details';
$l["cmdFieldsetAddress"]= 'Address';
$l["cmdFieldsetContact"]= 'Contact details';
$l["cmdFieldsetCompany"]= 'Company details';
$l["cmdFieldsetWork"]= 'Work';
$l["cmdPanelContact"]= 'Contact details';
$l["cmdPanelComments"]= 'Remarks';
$l["cmdSalutation"]= 'Dear';
$l["cmdMadam"]= 'madam';
$l["cmdSir"]= 'sir';
$l["btnDownloadTextDocument"]= 'Download TextDocument';
$l["cmdContactDetailsFor"]= 'Personal details for';
$l["cmdLInkFieldset"]= 'Links';
$l["cmdCompanyDetailsFor"]= 'Details for';
$l["cmdPanelCompany"]= 'Company details';
$l["cmdFormLabelBankNo"]= 'Bank number';
$l['bankBicNo'] = 'Bank BIC number';
$l["cmdFormLabelVatNo"]= 'VAT number';
$l["cmdFormLabelInvoiceEmail"]= 'Invoicing email';
$l["cmdFieldsetCompanyDetails"]= 'Company details';
$l["cmdCompanyDialog"]= 'Edit company';
$l["cmdPanelEmployees"]= 'Employees';
$l["cmdPanelEmployee"]= 'Employee';
$l["cmdAllEmployeesForThisCompany"]= 'All Employees for this company';
$l["cmdFieldsetVisitAddress"]= 'Visit address';
$l["cmdFieldsetPostAddress"]= 'Post address';
$l["cmdManageDialog"]= 'Manage';
$l["cmdAddAddressBook"]= 'Add address book';
$l["cmdDeleteAddressbook"]= 'Delete address book';
$l["cmdOwner"]= 'Owner';
$l["cmdPanelAddressbook"]= 'Address books';
$l["cmdPanelProperties"]= 'Properties';
$l["cmdContactDialog"]= 'Edit contact';
$l["cmdFormLabelFileType"]= 'File type';
$l["cmdFormLabelFile"]= 'File';	;
$l["cmdFormLabelValueSeperated"]= 'Values separated by';
$l["cmdFormLabelValueIncluded"]= 'Values encapsulated by';
$l["cmdFormLabelLinesEnded"]= 'Lines ended by';
$l["cmdUpload"]= 'Upload';
$l["cmdImport"]= 'Import';
$l["cmdExport"]= 'Export';
$l["users"]= 'Users';
$l["strSelectContact"]= 'Select contact';
$l["strSelectCompany"]= 'Select company';
$l["noAddressbooks"]= 'There are no address books';
$l["moveAll"]= 'The company and all employees will also be moved to the new address book. Are you sure you want to do this?';
$l["addressbook"]= 'Address book';
$l["addressbooks"]= 'Address books';
$l["sendMailing"]='Send mailing';
$l["importSuccessCount"]='Records imported successfully:';
$l["importSuccess"]='Records imported successfully!';
$l["searchOnSender"]='Lookup in address book';
$l["confirmCreate"]='Contact doesn\'t exist. Do you wish to create a new contact?';
$l["matchFields"]='Match the fields';
$l["advancedSearch"]='Advanced search';
$l["defaultAddressFormat"]='Default address format';
$l["defaultSalutation"]='Default salutation';
$l["explanationVariables"]='Explanation default salutation variables';
$l["explanationSex"]='Male and female form of salutation';
$l["searchQueryName"]='Search query name';
$l["enterSearchQueryName"]='Enter the name of the search query:';
$l["photo"]= 'Photo';
$l["deleteImage"]='Delete image';
$l["addAllSearchResults"]='Add all search results';
$l["confirmAddAllSearchResults"]='Are you sure you want to add all the search results to the address list?';
$l["moveEmployees"]='Move employees';
$l["emailAdded"]='Email address succesfully added to contact';
$l["exportWithCompanies"]='With companies';
$l["id"]='ID';
$l["exportPermission"]='Export permissions';
$l["crn"]='Company Reg. No.';
$l["iban"]='IBAN';
$l["unknownEmail"]= 'Unknown email address';
$l["strUnknownEmail"]= 'This email address is unknown. Do want to add this to a new contact or an existing contact?';
$l["newContact"] = "New Contact";
$l["existingContact"] = "Existing Contact";
$l["globalsettings_templatelabel"]= 'Template';
$l["globalsettings_allchangelabel"]= 'Change all?';
$l["globalsettings_renameall"]= 'Rename all?';
$l["createEmailSelected"]= 'Create email for selection';

$l['allAddressbooks'] = 'All Address books';
$l['notIncluded'] = 'Do not import';
$l['comment'] = 'Comment';
$l['bankNo'] = 'Bank number'; ;
$l['vatNo'] = 'VAT number';
$l['contactsGroup'] = 'Group';
$l['contact'] = 'Contact';
$l['company'] = 'Company';
$l['customers'] = 'Customers';
$l['suppliers'] = 'Suppliers';
$l['prospects'] = 'Prospects';
$l['contacts'] = 'Contacts';
$l['companies'] = 'Companies';
$l['newContactAdded']='New contact added';
$l['newContactFromSite']='New contact data have been added through a website form.';
$l['clickHereToView']='Click here to view the contact';
$l['contactFromAddressbook']='Contact from %s';
$l['companyFromAddressbook']='Company from %s';
$l['defaultSalutationTpl']='Dear [Mr./Mrs.] {middle_name} {last_name}';
$l['multipleSelected']='Multiple address books selected';
$l['incomplete_delete_contacts']='You don\'t have permission to delete all selected contacts';
$l['incomplete_delete_companies']='You don\'t have permission to delete all selected companies';
$l['emailAlreadyExists']='E-mail address is already added to this contact';
$l['emailDoesntExists']='E-mail address wasn\'t found';
$l['imageNotSupported']='The image you uploaded is not supported. Only gif, png and jpg images are supported.';
$l['no_addressbook_id'] = 'Invalid address book id has been passed with the request to the server!';
$l['undefined'] = '-';
$l['addresslistContact'] = 'Address list contact';

$l["companyId"] = "ID";
$l["companyUser_id"] = "User";
$l["companyAddressbook_id"] = "Addressbook";
$l["companyName"] = "Name";
$l["companyName2"] = "Name 2";
$l["companyAddress"] = "Address";
$l["companyAddress_no"] = "Address 2";
$l["companyZip"] = "ZIP/Postal";
$l["companyCity"] = "City";
$l["companyState"] = "State";
$l["companyCountry"] = "Country";
$l["companyPost_address"] = "Post Address";
$l["companyPost_address_no"] = "Post Address 2";
$l["companyPost_city"] = " Post City";
$l["companyPost_state"] = "Post State";
$l["companyPost_country"] = "Post Country";
$l["companyPost_zip"] = "Post ZIP/Postal";
$l["companyPhone"] = "Phone";
$l["companyFax"] = "Fax";
$l["companyEmail"] = "E-mail";
$l["companyHomepage"] = "Homepage";
$l["companyComment"] = "Comments";
$l["companyBank_no"] = "Bank Number";
$l["companyVat_no"] = "VAT Number";
$l["companyIban"] = "IBAN";
$l["companyCrn"] = "CRN";
$l["companyCtime"] = "Creation Time";
$l["companyMtime"] = "Modification Time";
$l["companyEmail_allowed"] = "Email allowed";
$l["companyFiles_folder_id"] = "Folder";

$l["contactId"] = "ID";
$l["contactUser_id"] = "User";
$l["contactAddressbook_id"] = "Addressbook";
$l["contactFirst_name"] = "First name";
$l["contactMiddle_name"] = "Middle name";
$l["contactLast_name"] = "Last name";
$l["contactInitials"] = "Initials";
$l["contactTitle"] = "Title";
$l["contactSex"] = "Sex";
$l["contactBirthday"] = "Birthday";
$l["contactEmail"] = "E-mail";
$l["contactEmail2"] = "E-mail 2";
$l["contactEmail3"] = "E-mail 3";
$l["contactCompany_id"] = "Company";
$l["contactDepartment"] = "Department";
$l["contactFunction"] = "Function";
$l["contactHome_phone"] = "Phone (Home)";
$l["contactWork_phone"] = "Phone (Work)";
$l["contactFax"] = "Fax (Home)";
$l["contactWork_fax"] = "Fax (Work)";
$l["contactCellular"] = "Mobile";
$l["contactCellular2"] = "2nd Mobile";
$l["contactCountry"] = "Country";
$l["contactState"] = "State";
$l["contactCity"] = "City";
$l["contactZip"] = "Zipcode";
$l["contactAddress"] = "Address";
$l["contactAddress_no"] = "Address number";
$l["contactComment"] = "Comments";
$l["contactCtime"] = "Creation time";
$l["contactMtime"] = "Modification time";
$l["contactSalutation"] = "Salutation";
$l["contactEmail_allowed"] = "Email allowed";
$l["contactFiles_folder_id"] = "Folder";
$l["contactGo_user_id"] = "User";
$l["contactSuffix"] = "Suffix";
$l["contactHomepage"] = "Homepage";

$l['mailingStatus'][0]="Waiting to start";
$l['mailingStatus'][1]="Running";
$l['mailingStatus'][2]="Finished";
$l['mailingStatus'][3]="Paused";

$l['createUser']='Create user';



$l["cmdPanelTemplate"]= 'Templates';
$l["cmdAddEmailTemplate"]= 'Add e-mail template';
$l["cmdAddOpenOfficeTemplate"]= 'Add OpenOffice.org template';
$l["cmdType"]= 'Type';
$l["cmdTemplateDialog"]= 'Edit template';
$l["cmdFormLabelReadNotification"]= 'Request the recipient to send a read notification';
$l["cmdAddMailing"]= 'Add address list';
$l["cmdDeleteMailing"]= 'Delete address list';
$l["cmdPanelMailings"]= 'Address lists';
$l["cmdEditMailingWindow"]= 'Edit address list';
$l["SelectOODocument"]= 'Select a template';
$l["SelectOODocumentWindowTitle"]= 'Select OpenOffice document';
$l["autoDataMyName"]= 'My Name';
$l["autoDataBeginning"]= 'Beginning';
$l["emailTemplate"]= 'E-mail template';
$l["sendingEmailAllowed"]= 'Sending e-mails to this e-mail address is allowed';
$l["enabledMailingGroups"]= 'Enabled address lists:';
$l["autoData"]= 'Autodata';
$l["selectMailingGroup"]='Select an address list';
$l["noMailingGroups"]='You don\'t have any address list';
$l["sentMailings"]='Sent newsletters';
$l["subject"]='Subject';
$l['status']='Status';
$l["sent"]='Sent';
$l["total"]='Total';
$l["errors"]='Errors';
$l["addEntireAddressbook"]='Add entire address book';
$l["selectAddressbook"]='Select an addressbook';
$l["defaultSalutationText"]='Enter a salutation that is used when the salutation for the recipient is unknown';
$l["filterMailings"]='Address list filter';
$l["enterName"]='Enter filename';
$l["pleaseEnterName"]='Please enter a filename for the new document';
$l["noAddressLists"]='No address lists';
$l["confirmAddEntireAddressbook"]='Are you sure you want to add everything in this addressbook to this addresslist?';
$l["noTemplate"]='No template';
$l["customContactFields"]='Custom contact fields';
$l["customCompanyFields"]='Custom company fields';
$l["customUserFields"]='Custom user fields';
$l["newsletters"]='Newsletters';
$l["addresslist"]='Address list';
$l["viewLog"]='View log';
$l["viewMessage"]='View message';
$l["pauseMailing"]='Pause sending';
$l["resumeMailing"]='Resume sending';
$l["unsubscribeLink"]='Unsubscribe link';
$l["unsubscribeHref"]='Unsubscribe href';
$l["addDocumentTemplate"]='Add document template';
$l["documentTemplate"]='Document template';


$l['templateAlreadyExists'] = 'The template you are trying to create already exists';
$l['mailingAlreadyExists'] = 'The mailing you are trying to create already exists';
$l['greet']='Best regards';
$l['unsubscribe']='Unsubscribe';
$l['unsubscription']='Click here to unsubscribe from this address list.';
$l['r_u_sure'] = 'Are you sure you want to unsubscribe from the address list?';
$l['delete_success'] = 'You have been successfully unsubscribed from the address list.';
$l['setCurrentTemplateAsDefault']='Set current template as default for myself';

$l['contactCustomFields']='Contacts custom fields';
$l['companyCustomFields']='Company custom fields';
$l['editUser']='Edit user';

$l['templateContent']='Document';

$l['addresslistIdMustBePositive']='This panel expects an address list ID that is positive, but did not receive one. Please contact the administrator.';
$l['male']='Male';
$l['female']='Female';
$l['importing']='Importing';
$l['contactUuid']='UUID';
$l['nRemovedFromAddresslist']='%n contacts have been identified and removed from the selected address list.';

$l['addToAddresslist']='Add to address list %s';
$l['addToAddresslistPrompt']='You are about to add the selected items to the address list %s. Do you want these items to exist only in %s?';
$l['addAddresslistSuccess']='The items have been successfully added to the address list.';

$l['addContactsSuccess'] = '%i contacts have been succesfully added to the address list.';

$l['searchForImages']='Search for images';
$l['downloadPhotoUrl']='Download photo URL';
$l['orBrowseComputer']='or upload from your computer';

$l['currentImage']='Current image';
$l['downloadFullImage']='Download full image';

$l['upcomingBirthdays'] = "Upcoming birthdays";
$l['age'] = "Age";
$l['actionDate']='Action date';
$l['selectCurrentActions']='Show active';
$l['showActieveToolTip']='Show only contacts that have a current action date.';
$l['linkedinUrl'] = 'LinkedIn URL';
$l['facebookUrl'] = 'Facebook URL';
$l['twitterUrl'] = 'Twitter URL';
$l['skypeName'] = 'Skype name';
$l['cmdPanelSocialMedia'] = 'Social media';

$l['setCurrentTemplateAsDefaultEAccount']='Set current template as default for this email account';

$l['callOnSkype'] = 'Call on Skype';

$l['userDefaultTemplate'] = 'User default template';

$l['exportContacts'] = 'Personal info';
$l['exportContactsWithCompanies'] = 'Personal and company info';

$l['privateAddress'] = 'Private address';
$l['exportContactsWithCompanies'] = 'Contacts with companies';

$l['mustBeSameAddressbook'] = 'The company of the contact must be in the same address book as the contact. Contact not saved.';
$l['exportContactsAsVcard'] = 'Export contacts as vcard';

$l["addEmployee"] = 'Add new';
$l["addExistingEmployee"] = 'Add existing';
$l["deleteWarningAdderessList"] = 'WARNING!!! All of the adderess list data including sen newslattser etc. will be deleted!';
